# django-writingfield

Django writing field is a custom form widget to enhances textareas in the django admin to give them a delicious fullscreen writing mode.

<video controls preload>
	<source src="http://cdn.obscuremetaphor.co.uk/video/crudedemo.mp4" type="video/mp4; codecs=&quot;avc1.42E01E,mp4a.40.2&quot;">
	<source src="http://cdn.obscuremetaphor.co.uk/video/crudedemo.webm" type="video/webm; codecs=&quot;vp8, vorbis&quot;">
</video>


For more information [read the docs](http://django-writingfield.obscuremetaphor.co.uk/)
